cmd

package
v0.9.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 4, 2025 License: Apache-2.0 Imports: 32 Imported by: 0

Documentation

Overview

Assembles application

Copyright 2025 NAME HERE EMAIL ADDRESS

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateEnrichersFlow

func CreateEnrichersFlow(plugin streams.Source, enrichers *model.EnrichersConfig, databaseContext *model.DatabaseContext, enricherCommon *model.EnricherCommonConfig) streams.Flow

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

type EnricherFlow

type EnricherFlow struct {
	// contains filtered or unexported fields
}

func NewEnricherFlow

func NewEnricherFlow(enrichers *model.EnrichersConfig, databaseContext *model.DatabaseContext, enricherCommon *model.EnricherCommonConfig) *EnricherFlow

func (*EnricherFlow) In

func (ef *EnricherFlow) In() chan<- any

func (*EnricherFlow) Out

func (ef *EnricherFlow) Out() <-chan any

func (*EnricherFlow) To

func (ef *EnricherFlow) To(sink streams.Sink)

func (*EnricherFlow) Via

func (ef *EnricherFlow) Via(flow streams.Flow) streams.Flow

Via asynchronously streams data to the given Flow and returns it. Here we cannot create dynamic flows.

Jump to